@@ -23,6 +23,7 @@ from gazoo_device import gdm_logger
 from gazoo_device.auxiliary_devices import raspberry_pi
 from gazoo_device.capabilities import matter_controller_chip_tool
 from gazoo_device.capabilities import matter_endpoints_accessor_chip_tool
+from gazoo_device.capabilities.matter_endpoints import dimmable_light
 from gazoo_device.capabilities.matter_endpoints import on_off_light
 
 logger = gdm_logger.get_logger()
@@ -37,6 +38,11 @@ class RaspberryPiMatterController(raspberry_pi.RaspberryPi):
   DEVICE_TYPE = "rpi_matter_controller"
   _OWNER_EMAIL = "gdm-authors@google.com"
 
+  @decorators.LogDecorator(logger)
+  def factory_reset(self) -> None:
+    """Factory resets the device."""
+    self.matter_controller.factory_reset()
+
   @decorators.CapabilityDecorator(
       matter_controller_chip_tool.MatterControllerChipTool)
   def matter_controller(
@@ -49,7 +55,7 @@ class RaspberryPiMatterController(raspberry_pi.RaspberryPi):
         shell_fn=self.shell,
         send_file_to_device=self.file_transfer.send_file_to_device,
         get_property_fn=self.get_property,
-        set_property_fn=self.get_manager().set_prop)
+        set_property_fn=self.set_property)
 
   @decorators.OptionalProperty
   def matter_node_id(self) -> Optional[int]:
@@ -76,6 +82,20 @@ class RaspberryPiMatterController(raspberry_pi.RaspberryPi):
 
   # ******************** Matter endpoint aliases ******************** #
 
+  @decorators.CapabilityDecorator(dimmable_light.DimmableLightEndpoint)
+  def dimmable_light(self) -> dimmable_light.DimmableLightEndpoint:
+    """Matter Dimmable Light endpoint instance.
+
+    Returns:
+      Dimmable Light endpoint instance.
+
+    Raises:
+      DeviceError when Dimmable Light endpoint is not supported on the
+      device.
+    """
+    return self.matter_endpoints.get_endpoint_instance_by_class(
+        dimmable_light.DimmableLightEndpoint)
+
   @decorators.CapabilityDecorator(on_off_light.OnOffLightEndpoint)
   def on_off_light(self) -> on_off_light.OnOffLightEndpoint:
     """Matter OnOff Light endpoint instance.
