@@ -20,16 +20,6 @@ from gazoo_device.capabilities.interfaces import capability_base
 class PwRPCCommonBase(capability_base.CapabilityBase):
   """Pigweed RPC common capability for devices communicating over PwRPC."""
 
-  @property
-  @abc.abstractmethod
-  def vendor_id(self) -> int:
-    """The vendor id of the device."""
-
-  @property
-  @abc.abstractmethod
-  def product_id(self) -> int:
-    """The product id of the device."""
-
   @property
   @abc.abstractmethod
   def software_version(self) -> int:
